"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.waitFinalize3Factory = exports.readSignedWithdrawalTx = exports.readUnsignedWithdrawalTx = exports.saveUnsignedWithdrawalTx = void 0;
const fs_1 = __importDefault(require("fs"));
const constants_1 = require("../constants");
function saveUnsignedWithdrawalTx(unsignedTx, id) {
    const fname = `${constants_1.forDefiDirectory}/${constants_1.forDefiUnsignedTxnDirectory}/${id}.unsignedTx.json`;
    if (fs_1.default.existsSync(fname)) {
        throw new Error(`unsignedTx file ${fname} already exists`);
    }
    const serialization = JSON.stringify(unsignedTx, null, 2);
    fs_1.default.mkdirSync(`${constants_1.forDefiDirectory}/${constants_1.forDefiUnsignedTxnDirectory}`, { recursive: true });
    fs_1.default.writeFileSync(fname, serialization);
}
exports.saveUnsignedWithdrawalTx = saveUnsignedWithdrawalTx;
function readUnsignedWithdrawalTx(id) {
    const fname = `${constants_1.forDefiDirectory}/${constants_1.forDefiUnsignedTxnDirectory}/${id}.unsignedTx.json`;
    if (!fs_1.default.existsSync(fname)) {
        throw new Error(`unsignedTx file ${fname} does not exist`);
    }
    const serialization = fs_1.default.readFileSync(fname).toString();
    return JSON.parse(serialization);
}
exports.readUnsignedWithdrawalTx = readUnsignedWithdrawalTx;
function readSignedWithdrawalTx(id) {
    const fname = `${constants_1.forDefiDirectory}/${constants_1.forDefiSignedTxnDirectory}/${id}.signedTx.json`;
    if (!fs_1.default.existsSync(fname)) {
        throw new Error(`signedTx file ${fname} does not exist`);
    }
    const serialization = fs_1.default.readFileSync(fname).toString();
    const resp = JSON.parse(serialization);
    if (!resp.signature) {
        throw new Error(`unsignedTx file ${fname} does not contain signature`);
    }
    return resp;
}
exports.readSignedWithdrawalTx = readSignedWithdrawalTx;
function waitFinalize3Factory(web3) {
    return function (address, func, delay = 1000, test = false) {
        return __awaiter(this, void 0, void 0, function* () {
            let totalDelay = 0;
            let nonce = yield web3.eth.getTransactionCount(address);
            let res = yield func();
            let backoff = 1.5;
            let cnt = 0;
            while ((yield web3.eth.getTransactionCount(address)) == nonce) {
                // if test is enabled, it will skip the timeout as it was getting stuck here
                if (!test)
                    yield new Promise((resolve) => { setTimeout(() => { resolve(); }, delay); });
                if (cnt < 8) {
                    totalDelay += delay;
                    delay = Math.floor(delay * backoff);
                    cnt++;
                }
                else {
                    throw new Error(`Response timeout after ${totalDelay}ms`);
                }
                console.log(`Delay backoff ${delay} (${cnt})`);
            }
            return res;
        });
    };
}
exports.waitFinalize3Factory = waitFinalize3Factory;
