"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.interactiveCli = void 0;
const prompts_1 = require("./prompts");
const screenConstants_1 = require("./screenConstants");
const constants_1 = require("./constants");
const commander_1 = require("commander");
const cli_1 = require("./cli");
const flareContract_1 = require("./flareContract");
const utils_1 = require("./ledger/utils");
const utils_2 = require("./utils");
const fs_1 = __importDefault(require("fs"));
/***
 * @description Handles all operations pertaining to the interactive CLL. Creates a list of arguments and internally calls the comamnder based CLI after taking the relevant inputs from the user.
 * @param baseargv List of base arguments passed to the application to invoke the interactive CLI
 * @returns {void}
 */
function interactiveCli(baseargv) {
    return __awaiter(this, void 0, void 0, function* () {
        const walletProperties = yield connectWallet();
        const task = yield selectTask();
        const program = new commander_1.Command("Flare Stake Tool");
        yield (0, cli_1.cli)(program);
        // First 4 info functions
        if (Object.keys(screenConstants_1.taskConstants).slice(0, 4).includes(task.toString())) {
            if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[0] || walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[1]) {
                const argsInfo = [...baseargv.slice(0, 2), "info", screenConstants_1.taskConstants[task], `--ctx-file=ctx.json`];
                yield program.parseAsync(argsInfo);
            }
            else if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[2] && walletProperties.path && walletProperties.network) {
                const argsInfo = [...baseargv.slice(0, 2), "info", screenConstants_1.taskConstants[task], `--env-path=${walletProperties.path}`, `--network=${walletProperties.network}`, "--get-hacked"];
                yield program.parseAsync(argsInfo);
            }
            else {
                console.log("Incorrect arguments passed!");
            }
        }
        // Functions for export and import to move funds between chains
        else if (Object.keys(screenConstants_1.taskConstants).slice(4, 6).includes(task.toString())) {
            if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[0] && fileExists("ctx.json")) {
                const { network: ctxNetwork, derivationPath: ctxDerivationPath } = readInfoFromCtx("ctx.json");
                if (ctxNetwork && ctxDerivationPath) {
                    const amount = yield prompts_1.prompts.amount();
                    const argsExport = [...baseargv.slice(0, 2), "transaction", `export${screenConstants_1.taskConstants[task].slice(-2)}`, '-a', `${amount.amount}`, "--blind", "true", "--derivation-path", ctxDerivationPath, `--network=${ctxNetwork}`, "--ledger"];
                    console.log("Please approve export transaction");
                    yield program.parseAsync(argsExport);
                    const argsImport = [...baseargv.slice(0, 2), "transaction", `import${screenConstants_1.taskConstants[task].slice(-2)}`, "--blind", "true", "--derivation-path", ctxDerivationPath, `--network=${ctxNetwork}`, "--ledger"];
                    console.log("Please approve import transaction");
                    yield program.parseAsync(argsImport);
                }
                else {
                    console.log("Missing params in ctx file");
                }
            }
            else if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[1] && fileExists("ctx.json")) {
                const { network: ctxNetwork, vaultId: ctxVaultId, publicKey: ctxPublicKey } = readInfoFromCtx("ctx.json");
                if (ctxNetwork && ctxVaultId && ctxPublicKey) {
                    const isContinue = yield prompts_1.prompts.forDefiContinue();
                    if (!isContinue.isContinue) {
                        const txnType = yield prompts_1.prompts.forDefiTxn();
                        const txnId = yield prompts_1.prompts.transactionId();
                        if (txnType.txn.includes("Export")) {
                            const amount = yield prompts_1.prompts.amount();
                            const argsExport = [...baseargv.slice(0, 2), "transaction", `export${screenConstants_1.taskConstants[task].slice(-2)}`, '-a', `${amount.amount}`, "-i", `${txnId.id}`];
                            yield program.parseAsync(argsExport);
                        }
                        else if (txnType.txn.includes("Import")) {
                            const argsImport = [...baseargv.slice(0, 2), "transaction", `import${screenConstants_1.taskConstants[task].slice(-2)}`, "-i", `${txnId.id}`];
                            yield program.parseAsync(argsImport);
                        }
                        const argsSign = makeForDefiArguments("sign", baseargv, txnId.id);
                        yield program.parseAsync(argsSign);
                    }
                    else {
                        const txnId = yield prompts_1.prompts.transactionId();
                        const argsFetch = makeForDefiArguments("fetch", baseargv, txnId.id);
                        yield program.parseAsync(argsFetch);
                        const argsSend = makeForDefiArguments("send", baseargv, txnId.id);
                        yield program.parseAsync(argsSend);
                    }
                }
                else {
                    console.log("Missing params in ctx file");
                }
            }
            else if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[2] && walletProperties.network && walletProperties.path) {
                const amount = yield prompts_1.prompts.amount();
                const argsExport = [...baseargv.slice(0, 2), "transaction", `export${screenConstants_1.taskConstants[task].slice(-2)}`, '-a', `${amount.amount}`, `--env-path=${walletProperties.path}`, `--network=${walletProperties.network}`, "--get-hacked"];
                console.log("Please approve export transaction");
                yield program.parseAsync(argsExport);
                const argsImport = [...baseargv.slice(0, 2), "transaction", `import${screenConstants_1.taskConstants[task].slice(-2)}`, `--env-path=${walletProperties.path}`, `--network=${walletProperties.network}`, "--get-hacked"];
                console.log("Please approve import transaction");
                yield program.parseAsync(argsImport);
            }
            else {
                console.log("Incorrect arguments passed!");
            }
        }
        // Adding a validator
        else if (Object.keys(screenConstants_1.taskConstants)[6] == task.toString()) {
            if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[0] && fileExists("ctx.json")) {
                const { network: ctxNetwork, derivationPath: ctxDerivationPath, ethAddress: ctxCAddress, publicKey: ctxPublicKey, flareAddress: ctxPAddress } = readInfoFromCtx("ctx.json");
                if (ctxNetwork && ctxDerivationPath && ctxPAddress && ctxCAddress) {
                    yield checkAddressRegistrationLedger(walletProperties.wallet, ctxNetwork, ctxDerivationPath, ctxCAddress, ctxPublicKey, ctxPAddress);
                    const { amount, nodeId, startTime, endTime, delegationFee } = yield getDetailsForDelegation(screenConstants_1.taskConstants[task]);
                    if (ctxNetwork && ctxDerivationPath && delegationFee) {
                        const argsValidator = [...baseargv.slice(0, 2), "transaction", screenConstants_1.taskConstants[task], '-n', `${nodeId}`, '-a', `${amount}`, '-s', `${startTime}`, '-e', `${endTime}`, '--delegation-fee', `${delegationFee}`, "--blind", "true", "--derivation-path", ctxDerivationPath, `--network=${ctxNetwork}`, "--ledger"];
                        yield program.parseAsync(argsValidator);
                    }
                    else {
                        console.log("Missing values for certain params");
                    }
                }
            }
            else if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[1] && fileExists("ctx.json")) {
                const { network: ctxNetwork, vaultId: ctxVaultId, publicKey: ctxPublicKey } = readInfoFromCtx("ctx.json");
                if (ctxNetwork && ctxVaultId && ctxPublicKey) {
                    const isContinue = yield prompts_1.prompts.forDefiContinue();
                    if (!isContinue.isContinue) {
                        const isRegistered = yield checkAddressRegistrationForDefi(ctxNetwork);
                        let txnId;
                        if (isRegistered) {
                            txnId = yield prompts_1.prompts.transactionId();
                            txnId = txnId.id;
                            const { amount, nodeId, startTime, endTime, delegationFee } = yield getDetailsForDelegation(screenConstants_1.taskConstants[task]);
                            const argsValidator = [...baseargv.slice(0, 2), "transaction", screenConstants_1.taskConstants[task], '-n', `${nodeId}`, `--network=${walletProperties.network}`, '-a', `${amount}`, '-s', `${startTime}`, '-e', `${endTime}`, '--delegation-fee', `${delegationFee}`, "-i", `${txnId}`];
                            yield program.parseAsync(argsValidator);
                        }
                        else {
                            txnId = yield registerAddressForDefi(walletProperties.wallet, ctxNetwork, ctxPublicKey);
                        }
                        const argsSign = makeForDefiArguments("sign", baseargv, txnId);
                        yield program.parseAsync(argsSign);
                    }
                    else {
                        const txnId = yield prompts_1.prompts.transactionId();
                        const argsFetch = makeForDefiArguments("fetch", baseargv, txnId.id);
                        yield program.parseAsync(argsFetch);
                        const argsSend = makeForDefiArguments("send", baseargv, txnId.id);
                        yield program.parseAsync(argsSend);
                    }
                }
                else {
                    console.log("Missing params in ctx file");
                }
            }
            else if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[2] && walletProperties.network && walletProperties.path) {
                yield checkAddressRegistrationPrivateKey(walletProperties.wallet, walletProperties.network, walletProperties.path);
                const { amount, nodeId, startTime, endTime, delegationFee } = yield getDetailsForDelegation(screenConstants_1.taskConstants[task]);
                const argsValidator = [...baseargv.slice(0, 2), "transaction", screenConstants_1.taskConstants[task], '-n', `${nodeId}`, `--network=${walletProperties.network}`, '-a', `${amount}`, '-s', `${startTime}`, '-e', `${endTime}`, '--delegation-fee', `${delegationFee}`, `--env-path=${walletProperties.path}`, "--get-hacked"];
                yield program.parseAsync(argsValidator);
            }
            else {
                console.log("only pvt key and ledger supported for staking right now");
            }
        }
        // Delegating to a Validator
        else if (Object.keys(screenConstants_1.taskConstants)[7] == task.toString()) {
            if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[0] && fileExists("ctx.json")) {
                const { network: ctxNetwork, derivationPath: ctxDerivationPath, ethAddress: ctxCAddress, publicKey: ctxPublicKey, flareAddress: ctxPAddress } = readInfoFromCtx("ctx.json");
                if (ctxNetwork && ctxDerivationPath && ctxPAddress && ctxCAddress) {
                    yield checkAddressRegistrationLedger(walletProperties.wallet, ctxNetwork, ctxDerivationPath, ctxCAddress, ctxPublicKey, ctxPAddress);
                    const { amount, nodeId, startTime, endTime } = yield getDetailsForDelegation(screenConstants_1.taskConstants[task]);
                    const argsDelegate = [...baseargv.slice(0, 2), "transaction", screenConstants_1.taskConstants[task], '-n', `${nodeId}`, '-a', `${amount}`, '-s', `${startTime}`, '-e', `${endTime}`, "--blind", "true", "--derivation-path", ctxDerivationPath, `--network=${ctxNetwork}`, "--ledger"];
                    yield program.parseAsync(argsDelegate);
                }
                else {
                    console.log("Missing params in ctx file");
                }
            }
            else if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[1] && fileExists("ctx.json")) {
                const { network: ctxNetwork, vaultId: ctxVaultId, publicKey: ctxPublicKey } = readInfoFromCtx("ctx.json");
                if (ctxNetwork && ctxVaultId && ctxPublicKey) {
                    const isContinue = yield prompts_1.prompts.forDefiContinue();
                    if (!isContinue.isContinue) {
                        const isRegistered = yield checkAddressRegistrationForDefi(ctxNetwork);
                        let txnId;
                        if (isRegistered) {
                            txnId = yield prompts_1.prompts.transactionId();
                            txnId = txnId.id;
                            const { amount, nodeId, startTime, endTime } = yield getDetailsForDelegation(screenConstants_1.taskConstants[task]);
                            const argsDelegate = [...baseargv.slice(0, 2), "transaction", screenConstants_1.taskConstants[task], '-n', `${nodeId}`, `--network=${walletProperties.network}`, '-a', `${amount}`, '-s', `${startTime}`, '-e', `${endTime}`, "-i", `${txnId}`];
                            yield program.parseAsync(argsDelegate);
                        }
                        else {
                            txnId = yield registerAddressForDefi(walletProperties.wallet, ctxNetwork, ctxPublicKey);
                        }
                        const argsSign = makeForDefiArguments("sign", baseargv, txnId);
                        yield program.parseAsync(argsSign);
                    }
                    else {
                        const txnId = yield prompts_1.prompts.transactionId();
                        const argsFetch = makeForDefiArguments("fetch", baseargv, txnId.id);
                        yield program.parseAsync(argsFetch);
                        const argsSend = makeForDefiArguments("send", baseargv, txnId.id);
                        yield program.parseAsync(argsSend);
                    }
                }
                else {
                    console.log("Missing params in ctx file");
                }
            }
            else if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[2] && walletProperties.network && walletProperties.path) {
                yield checkAddressRegistrationPrivateKey(walletProperties.wallet, walletProperties.network, walletProperties.path);
                const { amount, nodeId, startTime, endTime } = yield getDetailsForDelegation(screenConstants_1.taskConstants[task]);
                const argsDelegate = [...baseargv.slice(0, 2), "transaction", screenConstants_1.taskConstants[task], '-n', `${nodeId}`, `--network=${walletProperties.network}`, '-a', `${amount}`, '-s', `${startTime}`, '-e', `${endTime}`, `--env-path=${walletProperties.path}`, "--get-hacked"];
                yield program.parseAsync(argsDelegate);
            }
            else {
                console.log("only pvt key and ledger supported for delegation right now");
            }
        }
        // Mirror funds
        else if (Object.keys(screenConstants_1.taskConstants)[8] == (task.toString())) {
            if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[0] || walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[1]) {
                const argsInfo = [...baseargv.slice(0, 2), "info", screenConstants_1.taskConstants[task], `--ctx-file=ctx.json`];
                yield program.parseAsync(argsInfo);
            }
            else if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[2] && walletProperties.path && walletProperties.network) {
                const argsInfo = [...baseargv.slice(0, 2), "info", screenConstants_1.taskConstants[task], `--env-path=${walletProperties.path}`, `--network=${walletProperties.network}`, "--get-hacked"];
                yield program.parseAsync(argsInfo);
            }
            else {
                console.log("Incorrect arguments passed!");
            }
        }
        // Claim Rewards
        else if (Object.keys(screenConstants_1.taskConstants)[9] == task.toString()) {
            if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[0] && fileExists("ctx.json")) {
                const { network: ctxNetwork, derivationPath: ctxDerivationPath, ethAddress: ctxCAddress } = readInfoFromCtx("ctx.json");
                const isUnclaimed = yield (0, flareContract_1.isUnclaimedReward)(ctxCAddress, ctxNetwork);
                if (isUnclaimed)
                    yield claimRewardsLedger(walletProperties.wallet, ctxCAddress, ctxDerivationPath, ctxNetwork);
            }
            else if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[1] && fileExists("ctx.json")) {
                const context = (0, constants_1.contextFile)("ctx.json");
                const isUnclaimed = yield (0, flareContract_1.isUnclaimedReward)(context.cAddressHex, context.config.hrp);
                if (isUnclaimed) {
                    const isContinue = yield prompts_1.prompts.forDefiContinue();
                    const txnId = yield prompts_1.prompts.transactionId();
                    if (!isContinue.isContinue) {
                        yield claimRewardsForDefi(walletProperties.wallet, txnId.id);
                        const argsSign = makeForDefiArguments("sign", baseargv, txnId.id);
                        yield program.parseAsync(argsSign);
                    }
                    else {
                        const argsFetch = makeForDefiArguments("fetch", baseargv, txnId.id);
                        yield program.parseAsync(argsFetch);
                        const argsSend = makeForDefiArguments("send", baseargv, txnId.id);
                        yield program.parseAsync(argsSend);
                    }
                }
            }
            else if (walletProperties.wallet == Object.keys(screenConstants_1.walletConstants)[2]) {
                const context = (0, constants_1.contextEnv)(walletProperties.path, walletProperties.network);
                const isUnclaimed = yield (0, flareContract_1.isUnclaimedReward)(context.cAddressHex, context.config.hrp);
                if (isUnclaimed)
                    yield claimRewardsPrivateKey(walletProperties.wallet, context);
            }
        }
        else {
            console.log("Task not supported");
        }
    });
}
exports.interactiveCli = interactiveCli;
function connectWallet() {
    return __awaiter(this, void 0, void 0, function* () {
        const walletPrompt = yield prompts_1.prompts.connectWallet();
        const wallet = walletPrompt.wallet;
        if (wallet == Object.keys(screenConstants_1.walletConstants)[2]) {
            console.log(`${constants_1.colorCodes.redColor}Warning: You are connecting using your private key which is not recommended`);
            const pvtKeyPath = yield prompts_1.prompts.pvtKeyPath();
            const path = pvtKeyPath.pvtKeyPath;
            const network = yield selectNetwork();
            return { wallet, path, network };
        }
        else if (wallet == Object.keys(screenConstants_1.walletConstants)[1]) {
            const isCreateCtx = yield getCtxStatus();
            if (isCreateCtx) {
                const publicKey = yield prompts_1.prompts.publicKey();
                const network = yield selectNetwork();
                const vaultId = yield prompts_1.prompts.vaultId();
                const optionsObject = {
                    network,
                    blind: false,
                    ctxFile: 'ctx.json',
                    publicKey: publicKey.publicKey,
                    vaultId: vaultId.id
                };
                yield (0, cli_1.initCtxJsonFromOptions)(optionsObject);
            }
            return { wallet };
        }
        else if (wallet == Object.keys(screenConstants_1.walletConstants)[0]) {
            const isCreateCtx = yield getCtxStatus();
            let network;
            if (isCreateCtx) {
                network = yield selectNetwork();
                console.log("Fetching Addresses...");
                const pathList = yield (0, utils_1.getPathsAndAddresses)(network);
                const choiceList = yield createChoicesFromAddress(pathList);
                const selectedAddress = yield prompts_1.prompts.selectAddress(choiceList);
                const selectedDerivedAddress = pathList.find(item => item.ethAddress == selectedAddress.address);
                const selectedDerivationPath = selectedDerivedAddress === null || selectedDerivedAddress === void 0 ? void 0 : selectedDerivedAddress.derivationPath;
                const optionsObject = {
                    network,
                    blind: false,
                    ctxFile: 'ctx.json',
                    ledger: true
                };
                yield (0, cli_1.initCtxJsonFromOptions)(optionsObject, selectedDerivationPath);
            }
            return { wallet };
        }
        else {
            return { wallet };
        }
    });
}
function selectNetwork() {
    return __awaiter(this, void 0, void 0, function* () {
        const network = yield prompts_1.prompts.selectNetwork();
        return network.network;
    });
}
function selectTask() {
    return __awaiter(this, void 0, void 0, function* () {
        const task = yield prompts_1.prompts.selectTask();
        return task.task;
    });
}
function fileExists(filePath) {
    try {
        fs_1.default.accessSync(filePath, fs_1.default.constants.F_OK);
        return true;
    }
    catch (error) {
        return false;
    }
}
function readInfoFromCtx(filePath) {
    const ctxContent = fs_1.default.readFileSync('ctx.json', 'utf-8');
    const ctxData = JSON.parse(ctxContent);
    const publicKey = ctxData.publicKey;
    const network = ctxData.network;
    const ethAddress = ctxData.ethAddress || undefined;
    const flareAddress = ctxData.flareAddress;
    const derivationPath = ctxData.derivationPath || undefined;
    const vaultId = ctxData.vaultId || undefined;
    return { publicKey, network, ethAddress, flareAddress, derivationPath, vaultId };
}
function createChoicesFromAddress(pathList) {
    return __awaiter(this, void 0, void 0, function* () {
        const choiceList = [];
        for (let i = 0; i < 10; i++) {
            const choice = pathList[i].ethAddress;
            choiceList.push(`${i + 1}. ${choice}`);
        }
        return choiceList;
    });
}
function getCtxStatus() {
    return __awaiter(this, void 0, void 0, function* () {
        let isCreateCtx = true;
        const isFileExist = fileExists("ctx.json");
        if (isFileExist) {
            console.log(`${constants_1.colorCodes.magentaColor}You already have an existing Ctx file with the following parameters - ${constants_1.colorCodes.resetColor}`);
            const { network: ctxNetwork, publicKey: ctxPublicKey, ethAddress: ctxEthAddress, vaultId: ctxVaultId } = readInfoFromCtx("ctx.json");
            console.log(`${constants_1.colorCodes.orangeColor}Public Key:${constants_1.colorCodes.resetColor} ${ctxPublicKey}`);
            console.log(`${constants_1.colorCodes.orangeColor}Network:${constants_1.colorCodes.resetColor} ${ctxNetwork}`);
            if (ctxEthAddress) {
                console.log(`${constants_1.colorCodes.orangeColor}Eth Address:${constants_1.colorCodes.resetColor} ${ctxEthAddress}`);
            }
            if (ctxVaultId) {
                console.log(`${constants_1.colorCodes.orangeColor}Vault Id:${constants_1.colorCodes.resetColor} ${ctxVaultId}`);
            }
            const getUserChoice = yield prompts_1.prompts.ctxFile();
            const isContinue = getUserChoice.isContinue;
            if (isContinue) {
                isCreateCtx = false;
            }
            else {
                try {
                    fs_1.default.unlinkSync('ctx.json');
                    console.log('File "ctx.json" has been deleted.');
                }
                catch (error) {
                    console.error('An error occurred while deleting the file:', error);
                }
            }
        }
        return isCreateCtx;
    });
}
function getDetailsForDelegation(task) {
    return __awaiter(this, void 0, void 0, function* () {
        const amount = yield prompts_1.prompts.amount();
        const nodeId = yield prompts_1.prompts.nodeId();
        const startTime = yield prompts_1.prompts.unixTime("start");
        const endTime = yield prompts_1.prompts.unixTime("end");
        const delegationDetails = {
            amount: amount.amount,
            nodeId: nodeId.id,
            startTime: startTime.time,
            endTime: endTime.time
        };
        if (task == "stake") {
            const fee = yield prompts_1.prompts.delegationFee();
            return Object.assign(Object.assign({}, delegationDetails), { delegationFee: fee.fee });
        }
        return delegationDetails;
    });
}
function makeForDefiArguments(txnType, baseargv, txnId) {
    if (txnType == "sign") {
        const argsSign = [...baseargv.slice(0, 2), "forDefi", "sign", "-i", `${txnId}`];
        return argsSign;
    }
    if (txnType == "fetch") {
        const argsFetch = [...baseargv.slice(0, 2), "forDefi", "fetch", "-i", `${txnId}`];
        return argsFetch;
    }
    if (txnType == "send") {
        const argsSign = [...baseargv.slice(0, 2), "send", "-i", `${txnId}`];
        return argsSign;
    }
    return [];
}
function checkAddressRegistrationLedger(wallet, ctxNetwork, ctxDerivationPath, ctxCAddress, ctxPublicKey, ctxPAddress) {
    return __awaiter(this, void 0, void 0, function* () {
        const isRegistered = yield (0, flareContract_1.isAddressRegistered)(ctxCAddress, ctxNetwork);
        if (!isRegistered) {
            console.log("Note: You need to register your wallet address before you can delegate your funds");
            console.log("Please complete this registration transaction to proceed");
            const registerAddressParams = {
                publicKey: ctxPublicKey,
                pAddress: ctxPAddress,
                cAddress: ctxCAddress,
                network: ctxNetwork,
                wallet: wallet,
                derivationPath: ctxDerivationPath
            };
            yield (0, flareContract_1.registerAddress)(registerAddressParams);
            console.log(`${constants_1.colorCodes.greenColor}Address successfully registered${constants_1.colorCodes.resetColor}`);
        }
    });
}
function checkAddressRegistrationPrivateKey(wallet, ctxNetwork, pvtKeyPath) {
    return __awaiter(this, void 0, void 0, function* () {
        const context = (0, constants_1.contextEnv)(pvtKeyPath, ctxNetwork);
        const isRegistered = yield (0, flareContract_1.isAddressRegistered)(context.cAddressHex, ctxNetwork);
        if (!isRegistered) {
            console.log("Note: You need to register your wallet address before you can delegate your funds");
            console.log("Please complete this registration transaction to proceed");
            const [pubX, pubY] = context.publicKey;
            const compressedPubKey = (0, utils_2.compressPublicKey)(pubX, pubY).toString('hex');
            const registerAddressParams = {
                publicKey: compressedPubKey,
                pAddress: context.pAddressBech32,
                cAddress: context.cAddressHex,
                network: ctxNetwork,
                wallet: wallet,
                pvtKey: context.privkHex
            };
            const response = yield (0, utils_2.getUserInput)(`${constants_1.colorCodes.redColor}Warning: You are about to expose your private key to 800+ dependencies, and we cannot guarantee one of them is not malicious! \nThis command is not meant to be used in production, but for testing only!${constants_1.colorCodes.resetColor} \nProceed? (Y/N) `);
            if (response == 'Y' || response == 'y') {
                yield (0, flareContract_1.registerAddress)(registerAddressParams);
            }
            console.log(`${constants_1.colorCodes.greenColor}Address successfully registered${constants_1.colorCodes.resetColor}`);
        }
    });
}
function registerAddressForDefi(wallet, ctxNetwork, ctxPublicKey) {
    return __awaiter(this, void 0, void 0, function* () {
        console.log("Note: You need to register your wallet address before you can delegate your funds");
        console.log("Please complete this registration transaction to proceed");
        const txnId = yield prompts_1.prompts.transactionId();
        const context = (0, constants_1.contextFile)("ctx.json");
        const registerAddressParams = {
            publicKey: ctxPublicKey,
            pAddress: context.pAddressBech32,
            cAddress: context.cAddressHex,
            network: ctxNetwork,
            wallet: wallet,
            transactionId: txnId.id
        };
        yield (0, flareContract_1.registerAddress)(registerAddressParams);
        return txnId.id;
    });
}
function checkAddressRegistrationForDefi(ctxNetwork) {
    return __awaiter(this, void 0, void 0, function* () {
        const context = (0, constants_1.contextFile)("ctx.json");
        const isRegistered = yield (0, flareContract_1.isAddressRegistered)(context.cAddressHex, ctxNetwork);
        return isRegistered;
    });
}
function claimRewardsPrivateKey(wallet, ctx) {
    return __awaiter(this, void 0, void 0, function* () {
        const claimAmount = yield prompts_1.prompts.amount("to claim ");
        const isOwnerReceiver = yield prompts_1.prompts.isOwnerReceiver();
        const receiverAddress = isOwnerReceiver.isOwnerReceiver ? ctx.cAddressHex : yield prompts_1.prompts.receiverAddress();
        const claimRewardsParams = {
            claimAmount: claimAmount.amount,
            ownerAddress: ctx.cAddressHex,
            receiverAddress: receiverAddress.address,
            network: ctx.config.hrp,
            wallet: wallet,
            pvtKey: ctx.privkHex
        };
        const response = yield (0, utils_2.getUserInput)(`${constants_1.colorCodes.redColor}Warning: You are about to expose your private key to 800+ dependencies, and we cannot guarantee one of them is not malicious! \nThis command is not meant to be used in production, but for testing only!${constants_1.colorCodes.resetColor} \nProceed? (Y/N) `);
        if (response == 'Y' || response == 'y') {
            yield (0, flareContract_1.claimRewards)(claimRewardsParams);
        }
        console.log(`${constants_1.colorCodes.greenColor}Rewards successfully claimed${constants_1.colorCodes.resetColor}`);
    });
}
function claimRewardsLedger(wallet, ctxCAddress, ctxDerivationPath, ctxNetwork) {
    return __awaiter(this, void 0, void 0, function* () {
        const claimAmount = yield prompts_1.prompts.amount("to claim ");
        const isOwnerReceiver = yield prompts_1.prompts.isOwnerReceiver();
        const receiverAddress = isOwnerReceiver.isOwnerReceiver ? ctxCAddress : yield prompts_1.prompts.receiverAddress();
        const claimRewardsParams = {
            claimAmount: claimAmount.amount,
            ownerAddress: ctxCAddress,
            receiverAddress: receiverAddress.address,
            network: ctxNetwork,
            wallet: wallet,
            derivationPath: ctxDerivationPath
        };
        console.log("Please sign the transaction on your ledger");
        yield (0, flareContract_1.claimRewards)(claimRewardsParams);
        console.log(`${constants_1.colorCodes.greenColor}Rewards successfully claimed${constants_1.colorCodes.resetColor}`);
    });
}
function claimRewardsForDefi(wallet, transactionId) {
    return __awaiter(this, void 0, void 0, function* () {
        const claimAmount = yield prompts_1.prompts.amount("to claim ");
        const context = (0, constants_1.contextFile)("ctx.json");
        const isOwnerReceiver = yield prompts_1.prompts.isOwnerReceiver();
        const receiverAddress = isOwnerReceiver.isOwnerReceiver ? context.cAddressHex : yield prompts_1.prompts.receiverAddress();
        const claimRewardsParams = {
            claimAmount: claimAmount.amount,
            ownerAddress: context.cAddressHex,
            receiverAddress: receiverAddress.address,
            network: context.config.hrp,
            wallet: wallet,
            transactionId: transactionId
        };
        yield (0, flareContract_1.claimRewards)(claimRewardsParams);
    });
}
