"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchMirrorFunds = void 0;
const ethers_1 = require("ethers");
const constants_1 = require("./constants");
const utils_1 = require("../utils");
// creates contract instance
const getContractInstance = (contractAddress, contractABI, rpcUrl) => __awaiter(void 0, void 0, void 0, function* () {
    const provider = new ethers_1.ethers.JsonRpcProvider(rpcUrl);
    const contract = new ethers_1.ethers.Contract(contractAddress, contractABI, provider);
    return contract;
});
// creates pChainMirrorContract instance
const getPChainMirrorContractInstance = (ctx) => __awaiter(void 0, void 0, void 0, function* () {
    const rpcUrl = (0, constants_1.rpcFromNetwork)(ctx.config.hrp);
    const mirrorContractAddress = (0, constants_1.pChainStakeMirrorContractFromNetwork)(ctx.config.hrp);
    const contractInstance = yield getContractInstance(mirrorContractAddress, constants_1.pChainStakeMirrorABI, rpcUrl);
    return contractInstance;
});
// fetches staked amount from the mirror contract
const fetchStakedAmount = (ctx) => __awaiter(void 0, void 0, void 0, function* () {
    const pMirrorContract = yield getPChainMirrorContractInstance(ctx);
    const stakedAmount = yield pMirrorContract.stakesOf(ctx.cAddressHex);
    return stakedAmount[1].length == 0 ? 0 : parseInt(stakedAmount[1]);
});
// fetches current validator info
const fetchValidatorInfo = (ctx) => __awaiter(void 0, void 0, void 0, function* () {
    const validator = yield ctx.pchain.getCurrentValidators();
    return validator;
});
// fetches pending validator info
const fetchPendingValidatorInfo = (ctx) => __awaiter(void 0, void 0, void 0, function* () {
    const pendingValidator = yield ctx.pchain.getPendingValidators();
    return pendingValidator;
});
// fetches the delegation stake (from both current and pending validator) for the current user
const fetchDelegateStake = (ctx, validatorFunction) => __awaiter(void 0, void 0, void 0, function* () {
    var _a, _b, _c, _d, _e, _f, _g;
    const validatorsInfo = yield validatorFunction(ctx);
    const validatorData = validatorsInfo === null || validatorsInfo === void 0 ? void 0 : validatorsInfo.validators;
    let userStake = [];
    for (let i = 0; i < validatorData.length; i++) {
        for (let j = 0; j < (validatorData[i].delegators && ((_a = validatorData[i].delegators) === null || _a === void 0 ? void 0 : _a.length)); j++) {
            if (validatorData[i].delegators[j] &&
                validatorData[i].delegators[j].rewardOwner.addresses.includes(ctx.pAddressBech32)) {
                userStake.push({
                    stakeAmount: parseInt((_c = (_b = validatorData[i]) === null || _b === void 0 ? void 0 : _b.delegators[j]) === null || _c === void 0 ? void 0 : _c.stakeAmount),
                    startTime: parseInt((_e = (_d = validatorData[i]) === null || _d === void 0 ? void 0 : _d.delegators[j]) === null || _e === void 0 ? void 0 : _e.startTime),
                    endTime: parseInt((_g = (_f = validatorData[i]) === null || _f === void 0 ? void 0 : _f.delegators[j]) === null || _g === void 0 ? void 0 : _g.endTime)
                });
            }
        }
    }
    return userStake;
});
// calculates the total amount of delegation
const getTotalFromDelegation = (data) => {
    let total = 0;
    for (let i = 0; i < data.length; i++) {
        total += data[i].stakeAmount;
    }
    return total;
};
/**
 * @description returns the mirror fund details
 * @param ctx - context
 * @returns - total mirror funds and funds with start and end time
 */
const fetchMirrorFunds = (ctx) => __awaiter(void 0, void 0, void 0, function* () {
    const stakeFromMirrorContract = yield fetchStakedAmount(ctx);
    const delegationToCurrentValidator = yield fetchDelegateStake(ctx, fetchValidatorInfo);
    const delegationToPendingValidator = yield fetchDelegateStake(ctx, fetchPendingValidatorInfo);
    const totalDelegatedAmount = getTotalFromDelegation(delegationToCurrentValidator) +
        getTotalFromDelegation(delegationToPendingValidator) +
        stakeFromMirrorContract;
    const totalInFLR = (0, utils_1.integerToDecimal)(totalDelegatedAmount.toString(), 9);
    return {
        TotalAmount: totalInFLR,
        MirrorFunds: Object.assign(Object.assign({}, delegationToCurrentValidator), delegationToPendingValidator)
    };
});
exports.fetchMirrorFunds = fetchMirrorFunds;
