"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.prompts = void 0;
const inquirer_1 = __importDefault(require("inquirer"));
const constants_1 = require("./constants");
const screenConstants_1 = require("./screenConstants");
/**
 * Provides various prompts used in the CLI for user interaction.
 */
exports.prompts = {
    connectWallet: () => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'list',
                name: 'wallet',
                message: `${constants_1.colorCodes.magentaColor}How do you want to connect your wallet?${constants_1.colorCodes.resetColor}`,
                choices: [
                    ...Object.values(screenConstants_1.walletConstants)
                ],
                filter: (val) => {
                    const key = Object.keys(screenConstants_1.walletConstants).find(key => screenConstants_1.walletConstants[key] == val);
                    return key;
                }
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    pvtKeyPath: () => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'input',
                name: 'pvtKeyPath',
                message: `${constants_1.colorCodes.magentaColor}Enter Path to Private Key file ${constants_1.colorCodes.yellowColor}(E.g. /home/wallet/pvtKeyFile)${constants_1.colorCodes.resetColor}:`,
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    publicKey: () => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'input',
                name: 'publicKey',
                message: `${constants_1.colorCodes.magentaColor}Enter your secp256k1 curve public key ${constants_1.colorCodes.yellowColor}(E.g. 0x02efe41c5d213089cb7a9e808505e9084bb9eb2bf3aa8050ea92a5ae9e20e5a692)${constants_1.colorCodes.magentaColor}:${constants_1.colorCodes.resetColor}`,
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    amount: (amountPurpose = "") => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'input',
                name: 'amount',
                message: `${constants_1.colorCodes.magentaColor}Enter amount ${amountPurpose}${constants_1.colorCodes.yellowColor}(in FLR)${constants_1.colorCodes.magentaColor}:${constants_1.colorCodes.resetColor}`,
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    nodeId: () => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'input',
                name: 'id',
                message: `${constants_1.colorCodes.magentaColor}Enter Node NodeId ${constants_1.colorCodes.yellowColor}(E.g. NodeID-FQKTLuZHEsjCxPeFTFgsojsucmdyNDsz1)${constants_1.colorCodes.magentaColor}:${constants_1.colorCodes.resetColor}`,
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    unixTime: (timeType) => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'input',
                name: 'time',
                message: `${constants_1.colorCodes.magentaColor}Enter ${timeType} time${constants_1.colorCodes.yellowColor}(E.g. 1693185095)${constants_1.colorCodes.magentaColor}:${constants_1.colorCodes.resetColor}`,
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    ctxFile: () => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'list',
                name: 'isContinue',
                message: `${constants_1.colorCodes.magentaColor}Do you wish to continue with this?${constants_1.colorCodes.resetColor}`,
                choices: [
                    "yes",
                    "no"
                ],
                filter: (val) => {
                    return val == "yes" ? true : false;
                }
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    selectNetwork: () => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'list',
                name: 'network',
                message: `${constants_1.colorCodes.magentaColor}Which network do you want to connect to?${constants_1.colorCodes.resetColor}`,
                choices: [
                    ...Object.values(screenConstants_1.networkConstants)
                ],
                filter: (val) => {
                    const key = Object.keys(screenConstants_1.networkConstants).find(key => screenConstants_1.networkConstants[key] == val);
                    return key;
                }
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    selectTask: () => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'list',
                name: 'task',
                message: `${constants_1.colorCodes.magentaColor}What do you want to do?${constants_1.colorCodes.resetColor}`,
                choices: [
                    ...Object.keys(screenConstants_1.taskConstants)
                ],
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    selectAddress: (choiceList) => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'list',
                name: 'address',
                message: `${constants_1.colorCodes.magentaColor}Which address do you want to use?${constants_1.colorCodes.resetColor}`,
                choices: [
                    ...choiceList
                ],
                filter: (val) => {
                    const address = val.split(" ")[1];
                    return address;
                }
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    delegationFee: () => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'input',
                name: 'fee',
                message: `${constants_1.colorCodes.magentaColor}Enter delegation fee${constants_1.colorCodes.yellowColor}(E.g. 10)${constants_1.colorCodes.magentaColor}:${constants_1.colorCodes.resetColor}`,
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    vaultId: () => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'input',
                name: 'id',
                message: `${constants_1.colorCodes.magentaColor}Enter a ForDefi Vault Id${constants_1.colorCodes.yellowColor}(E.g. 42989fc9-xxxx-xxxx-xxxx-xxxxxxxxxxxx)${constants_1.colorCodes.magentaColor}:${constants_1.colorCodes.resetColor}`,
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    transactionId: () => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'input',
                name: 'id',
                message: `${constants_1.colorCodes.magentaColor}Enter a Transaction Id${constants_1.colorCodes.yellowColor}(E.g. abc-txn)${constants_1.colorCodes.magentaColor}:${constants_1.colorCodes.resetColor}`,
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    forDefiTxn: () => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'list',
                name: 'txn',
                message: `${constants_1.colorCodes.magentaColor}Which transaction do you want to do?${constants_1.colorCodes.resetColor}`,
                choices: [
                    "Export funds",
                    "Import funds"
                ],
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    forDefiContinue: () => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'list',
                name: 'isContinue',
                message: `${constants_1.colorCodes.magentaColor}Choose an option${constants_1.colorCodes.resetColor}`,
                choices: [
                    "Start new transaction",
                    "Continue existing transaction"
                ],
                filter: (val) => {
                    return val.includes("existing") ? true : false;
                }
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    isOwnerReceiver: () => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'list',
                name: 'isOwnerReceiver',
                message: `${constants_1.colorCodes.magentaColor}Where do you want to receive your rewards?${constants_1.colorCodes.resetColor}`,
                choices: [
                    "Send to my wallet",
                    "Receive with another wallet"
                ],
                filter: (val) => {
                    return val.includes("my") ? true : false;
                }
            },
        ];
        return inquirer_1.default.prompt(questions);
    }),
    receiverAddress: () => __awaiter(void 0, void 0, void 0, function* () {
        const questions = [
            {
                type: 'input',
                name: 'address',
                message: `${constants_1.colorCodes.magentaColor}Please enter the C-address where you want to receive your rewards:${constants_1.colorCodes.resetColor}`,
            },
        ];
        return inquirer_1.default.prompt(questions);
    })
};
